@@ -38,6 +38,9 @@ FAILEDOPERATION_DESCRIBESERVICEERROR = 'FailedOperation.DescribeServiceError'
 # 查询service列表失败。
 FAILEDOPERATION_DESCRIBESERVICELISTERROR = 'FailedOperation.DescribeServiceListError'
 
+# 更新 ingress 失败。
+FAILEDOPERATION_UPDATEINGRESSERROR = 'FailedOperation.UpdateIngressError'
+
 # 请求响应超时。
 INTERNALERROR_ACTIONREADTIMEOUT = 'InternalError.ActionReadTimeout'
 
@@ -164,6 +167,9 @@ INVALIDPARAMETERVALUE_ATLEASTONESCALERRULESHOULDBEAPPLIED = 'InvalidParameterVal
 # 只支持绑定一种弹性伸缩。
 INVALIDPARAMETERVALUE_AUTOSCALERLARGERTHANONE = 'InvalidParameterValue.AutoScalerLargerThanOne'
 
+# 弹性规则名称不合法, 长度必须小于20。
+INVALIDPARAMETERVALUE_AUTOSCALERNAMEINVALID = 'InvalidParameterValue.AutoScalerNameInvalid'
+
 # 不能覆盖其他应用的访问方式。
 INVALIDPARAMETERVALUE_CANNOTOVERWRITEOTHERAPPLICATIONSERVICE = 'InvalidParameterValue.CannotOverWriteOtherApplicationService'
 
@@ -176,6 +182,9 @@ INVALIDPARAMETERVALUE_CONFIGDATAALREADYEXIST = 'InvalidParameterValue.ConfigData
 # 配置不合法。
 INVALIDPARAMETERVALUE_CONFIGDATAINVALID = 'InvalidParameterValue.ConfigDataInvalid'
 
+# 创建环境createRegion参数错误。
+INVALIDPARAMETERVALUE_CREATENAMESPACEUNSUPPORTREGIONERROR = 'InvalidParameterValue.CreateNamespaceUnsupportRegionError'
+
 # 定时弹性伸缩目标实例数不合法。
 INVALIDPARAMETERVALUE_CRONHPAREPLICASINVALID = 'InvalidParameterValue.CronHpaReplicasInvalid'
 
